/*
* Copyright (C) 2023 Valentin Lorentz

* This program is free software: you can redistribute it and/or modify it under the
* terms of the GNU Affero General Public License version 3, as published by the Free
* Software Foundation.
*
* This program is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
* PARTICULAR PURPOSE.  See the GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/// Type and functions to manipulate attribute sets
use std::ops::Deref;

use im::HashMap;

use super::NixValue;

/// Representation of a Nix attribute set
#[derive(Clone, Debug, Default, PartialEq)]
pub struct AttrSet(HashMap<String, NixValue>);

impl AttrSet {
    pub fn new(entries: HashMap<String, NixValue>) -> AttrSet {
        AttrSet(entries)
    }

    /// Returns the old value, if any. See [`HashMap::insert`]
    pub fn insert(&mut self, key: String, value: NixValue) -> Option<NixValue> {
        self.0.insert(key, value)
    }

    #[inline(always)]
    pub fn get_or_insert(&mut self, key: String, value: NixValue) -> &mut NixValue {
        self.0.entry(key).or_insert(value)
    }
}

impl Deref for AttrSet {
    type Target = HashMap<String, NixValue>;

    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
