/*
* Copyright (C) 2023 Valentin Lorentz

* This program is free software: you can redistribute it and/or modify it under the
* terms of the GNU Affero General Public License version 3, as published by the Free
* Software Foundation.
*
* This program is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
* PARTICULAR PURPOSE.  See the GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*/

use autonix_eval::{AttrSet, Evaluator, NixValue, PureEvaluator};
use rnix::ast::Expr;

fn parse(s: &str) -> Expr {
    rnix::Root::parse(s).ok().unwrap().expr().unwrap()
}

#[test]
fn test_attrset() {
    assert_eq!(
        PureEvaluator.eval_expr(&parse(r#"{ a = "Foo"; b = "Bar"; }"#)),
        AttrSet::from(vec![
            ("a", NixValue::String("Foo".to_owned())),
            ("b", NixValue::String("Bar".to_owned()))
        ])
        .into()
    );
}

#[test]
fn test_attrset_get() {
    assert_eq!(
        PureEvaluator.eval_expr(&parse(r#"{ a = "Foo"; b = "Bar"; }.a"#)),
        NixValue::String("Foo".to_owned())
    );
    assert_eq!(
        PureEvaluator.eval_expr(&parse(r#"{ a = "Foo"; b = "Bar"; }.b"#)),
        NixValue::String("Bar".to_owned())
    );
}
